Class: Stagehand::Models::Action
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::Action
- Defined in:
- lib/stagehand/models/action.rb
Instance Attribute Summary collapse
-
#arguments ⇒ Array<String>?
Arguments to pass to the method.
-
#backend_node_id ⇒ Float?
Backend node ID for the element.
-
#description ⇒ String
Human-readable description of the action.
-
#method_ ⇒ String?
The method to execute (click, fill, etc.).
-
#selector ⇒ String
CSS selector or XPath for the element.
Instance Method Summary collapse
-
#initialize(description:, selector:, arguments: nil, backend_node_id: nil, method_: nil) ⇒ Object
constructor
Action object returned by observe and used by act.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, selector:, arguments: nil, backend_node_id: nil, method_: nil) ⇒ Object
Action object returned by observe and used by act
|
|
# File 'lib/stagehand/models/action.rb', line 36
|
Instance Attribute Details
#arguments ⇒ Array<String>?
Arguments to pass to the method
22 |
# File 'lib/stagehand/models/action.rb', line 22 optional :arguments, Stagehand::Internal::Type::ArrayOf[String] |
#backend_node_id ⇒ Float?
Backend node ID for the element
28 |
# File 'lib/stagehand/models/action.rb', line 28 optional :backend_node_id, Float, api_name: :backendNodeId |
#description ⇒ String
Human-readable description of the action
10 |
# File 'lib/stagehand/models/action.rb', line 10 required :description, String |
#method_ ⇒ String?
The method to execute (click, fill, etc.)
34 |
# File 'lib/stagehand/models/action.rb', line 34 optional :method_, String, api_name: :method |
#selector ⇒ String
CSS selector or XPath for the element
16 |
# File 'lib/stagehand/models/action.rb', line 16 required :selector, String |