Class: Stagehand::Models::ModelConfig::VertexModelConfigObject::ProviderOptions::Vertex
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::ModelConfig::VertexModelConfigObject::ProviderOptions::Vertex
- Defined in:
- lib/stagehand/models/model_config.rb,
sig/stagehand/models/model_config.rbs
Overview
Instance Attribute Summary collapse
-
#base_url ⇒ String?
Base URL for the Vertex AI provider.
-
#headers ⇒ Hash{Symbol=>String}?
Custom headers sent with every request to the Vertex AI provider.
-
#location ⇒ String
Google Cloud location for Vertex AI models.
-
#project ⇒ String
Google Cloud project ID for Vertex AI models.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
251 |
# File 'sig/stagehand/models/model_config.rbs', line 251 def initialize: ( |
Instance Attribute Details
#base_url ⇒ String?
Base URL for the Vertex AI provider
249 |
# File 'lib/stagehand/models/model_config.rb', line 249 optional :base_url, String, api_name: :baseURL |
#headers ⇒ Hash{Symbol=>String}?
Custom headers sent with every request to the Vertex AI provider
255 |
# File 'lib/stagehand/models/model_config.rb', line 255 optional :headers, Stagehand::Internal::Type::HashOf[String] |
#location ⇒ String
Google Cloud location for Vertex AI models
237 |
# File 'lib/stagehand/models/model_config.rb', line 237 required :location, String |
#project ⇒ String
Google Cloud project ID for Vertex AI models
243 |
# File 'lib/stagehand/models/model_config.rb', line 243 required :project, String |
Instance Method Details
#to_hash ⇒ {
258 |
# File 'sig/stagehand/models/model_config.rbs', line 258 def to_hash: -> { |