Class: Stagehand::Models::SessionExecuteParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::SessionExecuteParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stagehand/models/session_execute_params.rb
Overview
Defined Under Namespace
Modules: XStreamResponse Classes: AgentConfig, ExecuteOptions
Instance Attribute Summary collapse
- #agent_config ⇒ Stagehand::Models::SessionExecuteParams::AgentConfig
- #execute_options ⇒ Stagehand::Models::SessionExecuteParams::ExecuteOptions
-
#frame_id ⇒ String?
Target frame ID for the agent.
-
#id ⇒ String
Unique session identifier.
-
#should_cache ⇒ Boolean?
If true, the server captures a cache entry and returns it to the client.
-
#x_stream_response ⇒ Symbol, ...
Whether to stream the response via SSE.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, Float, Boolean, Stagehand::Models::SessionExecuteParams::ExecuteOptions::Variable::UnionMember3)
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stagehand::Internal::Type::BaseModel
Instance Attribute Details
#agent_config ⇒ Stagehand::Models::SessionExecuteParams::AgentConfig
21 |
# File 'lib/stagehand/models/session_execute_params.rb', line 21 required :agent_config, -> { Stagehand::SessionExecuteParams::AgentConfig }, api_name: :agentConfig |
#execute_options ⇒ Stagehand::Models::SessionExecuteParams::ExecuteOptions
26 27 28 |
# File 'lib/stagehand/models/session_execute_params.rb', line 26 required :execute_options, -> { Stagehand::SessionExecuteParams::ExecuteOptions }, api_name: :executeOptions |
#frame_id ⇒ String?
Target frame ID for the agent
34 |
# File 'lib/stagehand/models/session_execute_params.rb', line 34 optional :frame_id, String, api_name: :frameId, nil?: true |
#id ⇒ String
Unique session identifier
16 |
# File 'lib/stagehand/models/session_execute_params.rb', line 16 required :id, String |
#should_cache ⇒ Boolean?
If true, the server captures a cache entry and returns it to the client
40 |
# File 'lib/stagehand/models/session_execute_params.rb', line 40 optional :should_cache, Stagehand::Internal::Type::Boolean, api_name: :shouldCache |
#x_stream_response ⇒ Symbol, ...
Whether to stream the response via SSE
46 |
# File 'lib/stagehand/models/session_execute_params.rb', line 46 optional :x_stream_response, enum: -> { Stagehand::SessionExecuteParams::XStreamResponse } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stagehand/models/session_execute_params.rb', line 177
|
.variants ⇒ Array(String, Float, Boolean, Stagehand::Models::SessionExecuteParams::ExecuteOptions::Variable::UnionMember3)
|
|
# File 'lib/stagehand/models/session_execute_params.rb', line 270
|