Class: Stagehand::Models::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject
- Defined in:
- lib/stagehand/models/session_execute_params.rb,
sig/stagehand/models/session_execute_params.rbs
Defined Under Namespace
Classes: Auth, ProviderOptions
Instance Attribute Summary collapse
-
#api_key ⇒ String?
API key for the model provider.
-
#auth ⇒ Stagehand::Models::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject::Auth
Vertex provider authentication configuration.
-
#base_url ⇒ String?
Base URL for the model provider.
-
#headers ⇒ Hash{Symbol=>String}?
Custom headers sent with every request to the model provider.
-
#model_name ⇒ String
Model name string with provider prefix (e.g., 'openai/gpt-5-nano').
-
#provider ⇒ Symbol, :vertex
Vertex AI model provider.
-
#provider_options ⇒ Stagehand::Models::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject::ProviderOptions
Vertex provider-specific model configuration.
Instance Method Summary collapse
- #initialize(auth:, model_name:, provider_options:, api_key: nil, base_url: nil, headers: nil, provider: :vertex) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(auth:, model_name:, provider_options:, api_key: nil, base_url: nil, headers: nil, provider: :vertex) ⇒ Object
|
|
# File 'lib/stagehand/models/session_execute_params.rb', line 538
|
Instance Attribute Details
#api_key ⇒ String?
API key for the model provider
524 |
# File 'lib/stagehand/models/session_execute_params.rb', line 524 optional :api_key, String, api_name: :apiKey |
#auth ⇒ Stagehand::Models::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject::Auth
Vertex provider authentication configuration
496 |
# File 'lib/stagehand/models/session_execute_params.rb', line 496 required :auth, -> { Stagehand::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject::Auth } |
#base_url ⇒ String?
Base URL for the model provider
530 |
# File 'lib/stagehand/models/session_execute_params.rb', line 530 optional :base_url, String, api_name: :baseURL |
#headers ⇒ Hash{Symbol=>String}?
Custom headers sent with every request to the model provider
536 |
# File 'lib/stagehand/models/session_execute_params.rb', line 536 optional :headers, Stagehand::Internal::Type::HashOf[String] |
#model_name ⇒ String
Model name string with provider prefix (e.g., 'openai/gpt-5-nano')
502 |
# File 'lib/stagehand/models/session_execute_params.rb', line 502 required :model_name, String, api_name: :modelName |
#provider ⇒ Symbol, :vertex
Vertex AI model provider
508 |
# File 'lib/stagehand/models/session_execute_params.rb', line 508 required :provider, const: :vertex |
#provider_options ⇒ Stagehand::Models::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject::ProviderOptions
Vertex provider-specific model configuration
514 515 516 517 518 |
# File 'lib/stagehand/models/session_execute_params.rb', line 514 required :provider_options, -> { Stagehand::SessionExecuteParams::AgentConfig::Model::VertexModelConfigObject::ProviderOptions }, api_name: :providerOptions |
Instance Method Details
#to_hash ⇒ {
510 |
# File 'sig/stagehand/models/session_execute_params.rbs', line 510
def to_hash: -> {
|