Class: Stagehand::Models::SessionExecuteParams::ExecuteOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::SessionExecuteParams::ExecuteOptions
- Defined in:
- lib/stagehand/models/session_execute_params.rb
Defined Under Namespace
Modules: Variable
Instance Attribute Summary collapse
-
#highlight_cursor ⇒ Boolean?
Whether to visually highlight the cursor during execution.
-
#instruction ⇒ String
Natural language instruction for the agent.
-
#max_steps ⇒ Float?
Maximum number of steps the agent can take.
-
#tool_timeout ⇒ Float?
Timeout in milliseconds for each agent tool call.
-
#use_search ⇒ Boolean?
Whether to enable the web search tool powered by Browserbase Search API.
-
#variables ⇒ Hash{Symbol=>String, Float, Boolean, Stagehand::Models::SessionExecuteParams::ExecuteOptions::Variable::UnionMember3}?
Variables available to the agent via %variableName% syntax in supported tools.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stagehand::Internal::Type::BaseModel
Instance Attribute Details
#highlight_cursor ⇒ Boolean?
Whether to visually highlight the cursor during execution
193 |
# File 'lib/stagehand/models/session_execute_params.rb', line 193 optional :highlight_cursor, Stagehand::Internal::Type::Boolean, api_name: :highlightCursor |
#instruction ⇒ String
Natural language instruction for the agent
187 |
# File 'lib/stagehand/models/session_execute_params.rb', line 187 required :instruction, String |
#max_steps ⇒ Float?
Maximum number of steps the agent can take
199 |
# File 'lib/stagehand/models/session_execute_params.rb', line 199 optional :max_steps, Float, api_name: :maxSteps |
#tool_timeout ⇒ Float?
Timeout in milliseconds for each agent tool call
205 |
# File 'lib/stagehand/models/session_execute_params.rb', line 205 optional :tool_timeout, Float, api_name: :toolTimeout |
#use_search ⇒ Boolean?
Whether to enable the web search tool powered by Browserbase Search API
211 |
# File 'lib/stagehand/models/session_execute_params.rb', line 211 optional :use_search, Stagehand::Internal::Type::Boolean, api_name: :useSearch |
#variables ⇒ Hash{Symbol=>String, Float, Boolean, Stagehand::Models::SessionExecuteParams::ExecuteOptions::Variable::UnionMember3}?
Variables available to the agent via %variableName% syntax in supported tools
217 218 |
# File 'lib/stagehand/models/session_execute_params.rb', line 217 optional :variables, -> { Stagehand::Internal::Type::HashOf[union: Stagehand::SessionExecuteParams::ExecuteOptions::Variable] } |