Class: Stagehand::Models::SessionExecuteResponse::Data::CacheEntry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stagehand/models/session_execute_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cache_key:, entry:) ⇒ Object

Parameters:

  • cache_key (String)

    Opaque cache identifier computed from instruction, URL, options, and config

  • entry (Object)

    Serialized cache entry that can be written to disk



# File 'lib/stagehand/models/session_execute_response.rb', line 204

Instance Attribute Details

#cache_keyString

Opaque cache identifier computed from instruction, URL, options, and config

Returns:

  • (String)


196
# File 'lib/stagehand/models/session_execute_response.rb', line 196

required :cache_key, String, api_name: :cacheKey

#entryObject

Serialized cache entry that can be written to disk

Returns:

  • (Object)


202
# File 'lib/stagehand/models/session_execute_response.rb', line 202

required :entry, Stagehand::Internal::Type::Unknown