Class: Stagehand::Models::SessionExtractParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::SessionExtractParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stagehand/models/session_extract_params.rb
Overview
Defined Under Namespace
Modules: XStreamResponse Classes: Options
Instance Attribute Summary collapse
-
#frame_id ⇒ String?
Target frame ID for the extraction.
-
#id ⇒ String
Unique session identifier.
-
#instruction ⇒ String?
Natural language instruction for what to extract.
- #options ⇒ Stagehand::Models::SessionExtractParams::Options?
-
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema defining the structure of data to extract.
-
#x_stream_response ⇒ Symbol, ...
Whether to stream the response via SSE.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stagehand::Internal::Type::BaseModel
Instance Attribute Details
#frame_id ⇒ String?
Target frame ID for the extraction
22 |
# File 'lib/stagehand/models/session_extract_params.rb', line 22 optional :frame_id, String, api_name: :frameId, nil?: true |
#id ⇒ String
Unique session identifier
16 |
# File 'lib/stagehand/models/session_extract_params.rb', line 16 required :id, String |
#instruction ⇒ String?
Natural language instruction for what to extract
28 |
# File 'lib/stagehand/models/session_extract_params.rb', line 28 optional :instruction, String |
#options ⇒ Stagehand::Models::SessionExtractParams::Options?
33 |
# File 'lib/stagehand/models/session_extract_params.rb', line 33 optional :options, -> { Stagehand::SessionExtractParams::Options } |
#schema ⇒ Hash{Symbol=>Object}?
JSON Schema defining the structure of data to extract
39 |
# File 'lib/stagehand/models/session_extract_params.rb', line 39 optional :schema, Stagehand::Internal::Type::HashOf[Stagehand::Internal::Type::Unknown] |
#x_stream_response ⇒ Symbol, ...
Whether to stream the response via SSE
45 |
# File 'lib/stagehand/models/session_extract_params.rb', line 45 optional :x_stream_response, enum: -> { Stagehand::SessionExtractParams::XStreamResponse } |
Class Method Details
.variants ⇒ Array(Stagehand::Models::ModelConfig, String)
|
|
# File 'lib/stagehand/models/session_extract_params.rb', line 106
|