Class: Stagehand::Models::SessionStartResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stagehand/models/session_start_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(available:, session_id:, cdp_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Stagehand::Models::SessionStartResponse::Data for more details.

Parameters:

  • available (Boolean)
  • session_id (String)

    Unique Browserbase session identifier

  • cdp_url (String, nil) (defaults to: nil)

    CDP WebSocket URL for connecting to the Browserbase cloud browser (present when



# File 'lib/stagehand/models/session_start_response.rb', line 43

Instance Attribute Details

#availableBoolean

Returns:

  • (Boolean)


28
# File 'lib/stagehand/models/session_start_response.rb', line 28

required :available, Stagehand::Internal::Type::Boolean

#cdp_urlString?

CDP WebSocket URL for connecting to the Browserbase cloud browser (present when available)

Returns:

  • (String, nil)


41
# File 'lib/stagehand/models/session_start_response.rb', line 41

optional :cdp_url, String, api_name: :cdpUrl, nil?: true

#session_idString

Unique Browserbase session identifier

Returns:

  • (String)


34
# File 'lib/stagehand/models/session_start_response.rb', line 34

required :session_id, String, api_name: :sessionId