Class: Stagehand::Models::ModelConfig::VertexModelConfigObject::Auth
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::ModelConfig::VertexModelConfigObject::Auth
- Defined in:
- lib/stagehand/models/model_config.rb
Overview
Defined Under Namespace
Modules: Scopes Classes: Credentials
Instance Attribute Summary collapse
-
#credentials ⇒ Stagehand::Models::ModelConfig::VertexModelConfigObject::Auth::Credentials
Google Cloud service account credentials.
-
#project_id ⇒ String?
Google Cloud project ID used by google-auth-library.
-
#scopes ⇒ String, ...
Google auth scopes for the desired API request.
-
#type ⇒ Symbol, :googleServiceAccount
Use inline Google Cloud service account credentials for provider authentication.
-
#universe_domain ⇒ String?
Google Cloud universe domain.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(credentials:, project_id: nil, scopes: nil, universe_domain: nil, type: :googleServiceAccount) ⇒ Object
constructor
Vertex provider authentication configuration.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credentials:, project_id: nil, scopes: nil, universe_domain: nil, type: :googleServiceAccount) ⇒ Object
Vertex provider authentication configuration
|
|
# File 'lib/stagehand/models/model_config.rb', line 104
|
Instance Attribute Details
#credentials ⇒ Stagehand::Models::ModelConfig::VertexModelConfigObject::Auth::Credentials
Google Cloud service account credentials
78 |
# File 'lib/stagehand/models/model_config.rb', line 78 required :credentials, -> { Stagehand::ModelConfig::VertexModelConfigObject::Auth::Credentials } |
#project_id ⇒ String?
Google Cloud project ID used by google-auth-library
90 |
# File 'lib/stagehand/models/model_config.rb', line 90 optional :project_id, String, api_name: :projectId |
#scopes ⇒ String, ...
Google auth scopes for the desired API request
96 |
# File 'lib/stagehand/models/model_config.rb', line 96 optional :scopes, union: -> { Stagehand::ModelConfig::VertexModelConfigObject::Auth::Scopes } |
#type ⇒ Symbol, :googleServiceAccount
Use inline Google Cloud service account credentials for provider authentication
84 |
# File 'lib/stagehand/models/model_config.rb', line 84 required :type, const: :googleServiceAccount |
#universe_domain ⇒ String?
Google Cloud universe domain
102 |
# File 'lib/stagehand/models/model_config.rb', line 102 optional :universe_domain, String, api_name: :universeDomain |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stagehand/models/model_config.rb', line 195
|