Class: Stagehand::Models::SessionActResponse::Data::Result::Action
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stagehand::Models::SessionActResponse::Data::Result::Action
- Defined in:
- lib/stagehand/models/session_act_response.rb,
sig/stagehand/models/session_act_response.rbs
Instance Attribute Summary collapse
-
#arguments ⇒ Array<String>?
Arguments to pass to the method.
-
#backend_node_id ⇒ Float?
Backend node ID for the element.
-
#description ⇒ String
Human-readable description of the action.
-
#method_ ⇒ String?
The method to execute (click, fill, etc.).
-
#selector ⇒ String
CSS selector or XPath for the element.
Instance Method Summary collapse
-
#initialize(description:, selector:, arguments: nil, backend_node_id: nil, method_: nil) ⇒ Object
constructor
Action object returned by observe and used by act.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, selector:, arguments: nil, backend_node_id: nil, method_: nil) ⇒ Object
Action object returned by observe and used by act
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/stagehand/models/session_act_response.rb', line 79 class Action < Stagehand::Internal::Type::BaseModel # @!attribute description # Human-readable description of the action # # @return [String] required :description, String # @!attribute selector # CSS selector or XPath for the element # # @return [String] required :selector, String # @!attribute arguments # Arguments to pass to the method # # @return [Array<String>, nil] optional :arguments, Stagehand::Internal::Type::ArrayOf[String] # @!attribute backend_node_id # Backend node ID for the element # # @return [Float, nil] optional :backend_node_id, Float, api_name: :backendNodeId # @!attribute method_ # The method to execute (click, fill, etc.) # # @return [String, nil] optional :method_, String, api_name: :method # @!method initialize(description:, selector:, arguments: nil, backend_node_id: nil, method_: nil) # Action object returned by observe and used by act # # @param description [String] Human-readable description of the action # # @param selector [String] CSS selector or XPath for the element # # @param arguments [Array<String>] Arguments to pass to the method # # @param backend_node_id [Float] Backend node ID for the element # # @param method_ [String] The method to execute (click, fill, etc.) end |
Instance Attribute Details
#arguments ⇒ Array<String>?
Arguments to pass to the method
96 |
# File 'lib/stagehand/models/session_act_response.rb', line 96 optional :arguments, Stagehand::Internal::Type::ArrayOf[String] |
#backend_node_id ⇒ Float?
Backend node ID for the element
102 |
# File 'lib/stagehand/models/session_act_response.rb', line 102 optional :backend_node_id, Float, api_name: :backendNodeId |
#description ⇒ String
Human-readable description of the action
84 |
# File 'lib/stagehand/models/session_act_response.rb', line 84 required :description, String |
#method_ ⇒ String?
The method to execute (click, fill, etc.)
108 |
# File 'lib/stagehand/models/session_act_response.rb', line 108 optional :method_, String, api_name: :method |
#selector ⇒ String
CSS selector or XPath for the element
90 |
# File 'lib/stagehand/models/session_act_response.rb', line 90 required :selector, String |
Instance Method Details
#to_hash ⇒ {
109 |
# File 'sig/stagehand/models/session_act_response.rbs', line 109
def to_hash: -> {
|